Method: Authlogic::ControllerAdapters::RackAdapter#cookies

Defined in:
lib/authlogic/controller_adapters/rack_adapter.rb

#cookiesObject

Rack Requests stores cookies with not just the value, but also with flags and expire information in the hash. Authlogic does not like this, so we drop everything except the cookie value.



64
65
66
67
68
69
# File 'lib/authlogic/controller_adapters/rack_adapter.rb', line 64

def cookies
  controller
    .cookies
    .map { |key, value_hash| { key => value_hash[:value] } }
    .inject(:merge) || {}
end