Method: Authlogic::CryptoProviders::BCrypt.cost
- Defined in:
- lib/authlogic/crypto_providers/bcrypt.rb
.cost ⇒ Object
This is the :cost option for the BCrpyt library. The higher the cost the more secure it is and the longer is take the generate a hash. By default this is 10. Set this to any value >= the engine’s minimum (currently 4), play around with it to get that perfect balance between security and performance.
63 64 65 |
# File 'lib/authlogic/crypto_providers/bcrypt.rb', line 63 def cost @cost ||= 10 end |