Module: Authlogic::Session::ActiveRecordTrickery::InstanceMethods
- Defined in:
- lib/authlogic/session/active_record_trickery.rb
Instance Method Summary collapse
-
#new_record? ⇒ Boolean
Don’t use this yourself, this is to just trick some of the helpers since this is the method it calls.
-
#to_model ⇒ Object
For rails >= 3.0.
Instance Method Details
#new_record? ⇒ Boolean
Don’t use this yourself, this is to just trick some of the helpers since this is the method it calls.
51 52 53 |
# File 'lib/authlogic/session/active_record_trickery.rb', line 51 def new_record? new_session? end |
#to_model ⇒ Object
For rails >= 3.0
56 57 58 |
# File 'lib/authlogic/session/active_record_trickery.rb', line 56 def to_model self end |